@@ -1,6 +1,7 @@
-from labelbox import Client
 from labelbase import Client as baseClient
+from labelbox import Client
 import pandas
+from tqdm import tqdm
 from concurrent.futures import ThreadPoolExecutor, as_completed
 
 def create_upload_dict(df:pandas.core.frame.DataFrame, lb_client:Client, base_client:baseClient, row_data_col:str, 
@@ -37,9 +38,14 @@ def create_upload_dict(df:pandas.core.frame.DataFrame, lb_client:Client, base_cl
                     global_key_col, external_id_col, metadata_index, local_files, divider
                 )
             )
-        for f in as_completed(futures):
-            res = f.result()
-            global_key_to_upload_dict[str(res["global_key"])] = res  
+        if verbose:
+            for f in tqdm(as_completed(futures)):
+                res = f.result()
+                global_key_to_upload_dict[str(res["global_key"])] = res      
+        else:
+            for f in as_completed(futures):
+                res = f.result()
+                global_key_to_upload_dict[str(res["global_key"])] = res             
     if verbose:
         print(f'Generated upload list - {len(global_key_to_upload_dict)} data rows to upload')
     return global_key_to_upload_dict  
@@ -63,20 +69,19 @@ def create_data_rows(lb_client:Client, base_client:baseClient, row:pandas.core.s
     Returns:
         Two items - the global_key, and a dictionary with "row_data", "global_key", "external_id" and "metadata_fields" keys
     """
-    row_data_str = str(row[row_data_col])
-    row_data = base_client.connector.upload_local_file(lb_client=lb_client, file_path=row_data_str) if local_files else row_data_str
+    row_data = base_client.upload_local_file(file_path=str(row[row_data_col])) if local_files else str(row[row_data_col])
     metadata_fields = [{"schema_id" : metadata_name_key_to_schema['lb_integration_source'], "value" : "Pandas"}]
     if metadata_index:
         for metadata_field_name in metadata_index.keys():
-            metadata_value = base_client.process_metadata_value(
+            input_metadata = base_client.process_metadata_value(
                 metadata_value=row[metadata_field_name],
                 metadata_type=metadata_index[metadata_field_name], 
                 parent_name=metadata_field_name,
                 metadata_name_key_to_schema=metadata_name_key_to_schema, 
                 divider=divider
             )
-            if metadata_value:
-                metadata_fields.append({"schema_id" : metadata_name_key_to_schema[metadata_field_name], "value" : metadata_value})
+            if input_metadata:
+                metadata_fields.append({"schema_id" : metadata_name_key_to_schema[metadata_field_name], "value" : input_metadata})
             else:
                 continue
     return {"row_data":row_data,"global_key":str(row[global_key_col]),"external_id":str(row[external_id_col]),"metadata_fields":metadata_fields}                
